@@ -21,7 +21,6 @@
 __docformat__ = "restructuredtext en"
 
 import os
-import sys
 from os.path import join
 
 distname = "logilab-common"
@@ -29,13 +28,12 @@ modname = "common"
 subpackage_of = "logilab"
 subpackage_master = True
 
-numversion = (1, 9, 6)
+numversion = (2, 0, 0)
 version = ".".join([str(num) for num in numversion])
 
 license = "LGPL"  # 2.1 or later
 description = "collection of low-level Python packages and modules" " used by Logilab projects"
-web = "http://www.logilab.org/project/%s" % distname
-mailinglist = "mailto://python-projects@lists.logilab.org"
+web = "https://forge.extranet.logilab.fr/open-source/logilab-common"
 author = "Logilab"
 author_email = "contact@logilab.fr"
 
@@ -43,21 +41,19 @@ author_email = "contact@logilab.fr"
 scripts = [join("bin", "logilab-pytest")]
 include_dirs = [join("test", "data")]
 
-__depends__ = {
-    "setuptools": None,
-    "mypy-extensions": None,
-    "typing_extensions": None,
-}
+install_requires = [
+    "setuptools",
+    "mypy-extensions",
+    "typing_extensions",
+    'importlib_metadata>=6,<7; python_version < "3.10"',
+]
 tests_require = [
     "pytz",
     "egenix-mx-base",
 ]
 
 if os.name == "nt":
-    __depends__["colorama"] = None
-
-if sys.version_info < (3, 8):
-    __depends__["importlib_metadata"] = None
+    install_requires.append("colorama")
 
 classifiers = [
     "Topic :: Utilities",
