@@ -25,6 +25,8 @@ import inspect
 from enum import Enum
 from warnings import warn
 from functools import WRAPPER_ASSIGNMENTS, WRAPPER_UPDATES
+from importlib import import_module
+
 from typing import Any, Callable, Dict, Optional, Type
 from typing_extensions import Protocol
 
@@ -34,6 +36,16 @@ else:
     import importlib_metadata
 
 
+class FakeDistribution(importlib_metadata.Distribution):
+    "see https://github.com/python/importlib_metadata/blob/main/CHANGES.rst#v600"
+
+    def locate_file(self):
+        pass
+
+    def read_text(self):
+        pass
+
+
 def _unstack_all_deprecation_decorators(function):
     """
     This is another super edge magic case which is needed because we uses
@@ -96,7 +108,7 @@ def lazy_wraps(wrapped: Callable) -> Callable:
     return update_wrapper_attributes
 
 
-class DeprecationWrapper(object):
+class DeprecationWrapper:
     """proxy to print a warning on access to any attribute of the wrapped object"""
 
     def __init__(
@@ -161,6 +173,10 @@ _cached_path_to_package: Optional[Dict[str, Optional[str]]] = None
 
 
 def _get_package_name(python_object) -> Optional[str]:
+    # only do this work if we are in a pytest session
+    if "COLLECT_DEPRECATION_WARNINGS_PACKAGE_NAME" not in os.environ:
+        return None
+
     global _cached_path_to_package
 
     if _cached_path_to_package is None:
@@ -168,7 +184,7 @@ def _get_package_name(python_object) -> Optional[str]:
         # mypy fails to understand the result of .discover(): Cannot
         # instantiate abstract class 'Distribution' with abstract attributes
         # 'locate_file' and 'read_text'
-        for distribution in importlib_metadata.Distribution().discover():  # type: ignore
+        for distribution in FakeDistribution().discover():  # type: ignore
             # sometime distribution has a "name" attribute, sometime not
             if distribution.files and hasattr(distribution, "name"):
                 for file in distribution.files:
@@ -201,11 +217,11 @@ def send_warning(
     compatible version.
     """
     if module_name and version:
-        reason = "[%s %s] %s" % (module_name, version, reason)
+        reason = f"[{module_name} {version}] {reason}"
     elif module_name:
-        reason = "[%s] %s" % (module_name, reason)
+        reason = f"[{module_name}] {reason}"
     elif version:
-        reason = "[%s] %s" % (version, reason)
+        reason = f"[{version}] {reason}"
 
     warn(
         deprecation_class(reason, **deprecation_class_kwargs), stacklevel=stacklevel  # type: ignore
@@ -343,11 +359,6 @@ def callable_renamed(
     return wrapped
 
 
-renamed: Callable[[str, Callable, Optional[str]], Callable] = callable_renamed(
-    old_name="renamed", new_function=callable_renamed
-)
-
-
 def argument_removed(old_argument_name: str, version: Optional[str] = None) -> Callable:
     """
     callable decorator to allow getting backward compatibility for renamed keyword arguments.
@@ -388,8 +399,6 @@ def argument_removed(old_argument_name: str, version: Optional[str] = None) -> C
     return _wrap
 
 
-@argument_removed("name")
-@argument_removed("doc")
 def callable_deprecated(
     reason: Optional[str] = None, version: Optional[str] = None, stacklevel: int = 2
 ) -> Callable:
@@ -430,11 +439,6 @@ class CallableDeprecatedCallable(Protocol):
         ...
 
 
-deprecated: CallableDeprecatedCallable = callable_renamed(
-    old_name="deprecated", new_function=callable_deprecated
-)
-
-
 def _generate_class_deprecated():
     class _class_deprecated(type):
         """metaclass to print a warning on instantiation of a deprecated class"""
@@ -608,8 +612,6 @@ def argument_renamed(old_name: str, new_name: str, version: Optional[str] = None
     return _wrap
 
 
-@argument_renamed(old_name="modpath", new_name="module_path")
-@argument_renamed(old_name="objname", new_name="object_name")
 def callable_moved(
     module_name: str,
     object_name: str,
@@ -629,7 +631,7 @@ def callable_moved(
     """
     # in case the callable has been renamed
     new_name = new_name if new_name is not None else object_name
-    old_module = _get_module_name(3)
+    old_module = _get_module_name(1)
 
     message = "object %s.%s has been moved to %s.%s" % (
         old_module,
@@ -639,9 +641,7 @@ def callable_moved(
     )
 
     def callnew(*args, **kwargs):
-        from logilab.common.modutils import load_module_from_name
-
-        m = load_module_from_name(module_name)
+        m = import_module(module_name)
 
         send_warning(
             message,
@@ -665,11 +665,6 @@ def callable_moved(
     return callnew
 
 
-moved: Callable[[Optional[str], Optional[str], int], Callable] = callable_renamed(
-    old_name="moved", new_function=callable_moved
-)
-
-
 def class_renamed(
     old_name: str,
     new_class: type,
@@ -690,7 +685,7 @@ def class_renamed(
     """
     class_dict: Dict[str, Any] = {}
     if message is None:
-        message = "%s is deprecated, use %s instead" % (old_name, get_real__name__(new_class))
+        message = f"{old_name} is deprecated, use {get_real__name__(new_class)} instead"
 
     class_dict["__deprecation_warning__"] = message
     class_dict["__deprecation_warning_class__"] = deprecated_warning_class
