@@ -1,22 +1,31 @@
 """unittest_registry data file"""
 from logilab.common.registry import yes, RegistrableObject, RegistrableInstance
 
-class Proxy(object):
+
+class Proxy:
     """annoying object should that not be registered, nor cause error"""
+
     def __getattr__(self, attr):
         return 1
 
+
 trap = Proxy()
 
+
 class AppObjectClass(RegistrableObject):
-    __registry__ = 'zereg'
-    __regid__ = 'appobject1'
+    __registry__ = "zereg"
+    __regid__ = "appobject1"
+    __module__ = "regobjects"
     __select__ = yes()
 
+
 class AppObjectInstance(RegistrableInstance):
-    __registry__ = 'zereg'
+    __registry__ = "zereg"
+    __module__ = "regobjects"
     __select__ = yes()
+
     def __init__(self, regid):
         self.__regid__ = regid
 
-appobject2 = AppObjectInstance('appobject2')
+
+appobject2 = AppObjectInstance("appobject2")
